@@ -97,7 +97,7 @@ int main(int argc, char *argv[])
     int modeset = FALSE;
     int nvswitch = FALSE;
     int nvlink = FALSE;
-    int nv_cap = FALSE;
+    int enable_auto_online_movable = FALSE;
     int unused;
 
     while (1)
@@ -148,8 +148,6 @@ int main(int argc, char *argv[])
                 nvlink = TRUE;
                 break;
             case 'f':
-                nv_cap = TRUE;
-
                 if (num_cap_files < ARRAY_LEN(cap_files))
                 {
                     cap_files[num_cap_files++] = strval;
@@ -160,6 +158,9 @@ int main(int argc, char *argv[])
                     exit(1);
                 }
                 break;
+            case 'a':
+                enable_auto_online_movable = TRUE;
+                break;
             default:
                 nv_error_msg("Invalid commandline, please run `%s --help` "
                              "for usage information.\n", argv[0]);
@@ -225,6 +226,15 @@ int main(int argc, char *argv[])
             }
         }
     }
+    else if (enable_auto_online_movable)
+    {
+        /* Enable auto onlining mode online_movable */
+        ret = nvidia_enable_auto_online_movable(0);
+        if (!ret)
+        {
+            goto done;
+        }
+    }
     else
     {
         /* Load the kernel module. */
@@ -264,19 +274,16 @@ int main(int argc, char *argv[])
         }
     }
 
-    if (nv_cap)
+    for (i = 0; i < num_cap_files; i++)
     {
-        for (i = 0; i < num_cap_files; i++)
+        ret = nvidia_cap_mknod(cap_files[i], &unused);
+        if (!ret)
         {
-            ret = nvidia_cap_mknod(cap_files[i], &unused);
-            if (!ret)
-            {
-                goto done;
-            }
+            goto done;
         }
     }
 
- done:
+done:
 
     return !ret;
 }
